<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Blog;
use Carbon\Carbon;
use Auth;
use Str;

class BlogController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $blog= Blog::where('status',1)->get();
        return view('admin.blog.index',compact('blog'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('admin.blog.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
          
			'blog_name'=>'required',
			'blog_date'=>'required',
			'blog_image'=>'required',
			'blog_description'=>'required',
			
        ]);
        $data=$request->blog_image;
        $unique_id=uniqid();
            
            $blog = new Blog;         
            $blog->status =1;
            $blog->uploaded_by = Auth::user()->id;
            $blog->blog_name = $request->blog_name;
            $blog->blog_date = $request->blog_date;           
            $blog->blog_description = $request->blog_description;
            $slug = Str::slug($request->blog_name, '-');
            $blog->blog_slug = $slug;
            $blog->unique_id=$unique_id;
            if ($request->hasFile('blog_image')) {
                $image = $request->file('blog_image');
                $filename = $image->getClientOriginalName();
                $destinationPath = public_path('uploads/blog_image');
                $image->move($destinationPath, $filename);
                $blog->blog_image= "uploads/blog_image/" . $filename;
            }
            $blog->save();  
            
        
            session()->flash('success_msg', 'Blog created successfully');
            return redirect()->route('blog.index');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $id=Blog::where('unique_id',$id)->value('id');
        $row=Blog::find($id);
        return view('admin.blog.edit',compact('row'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
          
            'blog_name'=>'required',
			'blog_image'=>'required',
			'blog_description'=>'required',
			
        ]);

            $blog = Blog::find($id); 
            $blog->uploaded_by = Auth::user()->id;
            $blog->blog_name = $request->blog_name;          
            $blog->blog_description = $request->blog_description;
            $slug = Str::slug($request->blog_name, '-');
            $blog->blog_slug = $slug;
            if ($request->hasFile('blog_image')) {
                $image = $request->file('blog_image');
                $filename = $image->getClientOriginalName();
                $destinationPath = public_path('uploads/blog_image');
                $image->move($destinationPath, $filename);
                $blog->blog_image= "uploads/blog_image/" . $filename;
            }
            
            $blog->save();  
            return redirect()->route('blog.index');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $blog_id=Blog::where('unique_id',$id)->value('id');
        
        $blog=Blog::find($blog_id);
        $blog->status="2";
        $blog->save();
        
        session()->flash('success_msg', 'Blog has been deleted successfully');
        return back();
    }
}
